# WeatherBot

* This is a bot that sends weather information to a selected stream on
  request.

* Weather information is brought to the website using an
OpenWeatherMap API. The bot posts the weather information to the
stream from which the user inputs the message.  If the user inputs a
city that does not exist, the bot displays a "Sorry, city not found"
message.

* Before using this bot, you have to generate an OpenWeatherMap API
  key and replace the dummy value in weather.conf.

![Example Usage](assets/screen1.png)
![Wrong City](assets/screen2.png)
